@@ -6,7 +6,7 @@ from i2.signatures import Sig, name_of_obj, Command as _Command
 import streamlit.bootstrap
 
 run_streamlit = partial(
-    streamlit.bootstrap.run, command_line="", args=[], flag_options={}
+    streamlit.bootstrap.run, command_line='', args=[], flag_options={}
 )
 
 
@@ -26,20 +26,19 @@ class Command(_Command):
                 yield k, v
 
         return self.func(
-            *exaecute_commands_in_args(),
-            **dict(execute_commands_in_kwargs()),
+            *exaecute_commands_in_args(), **dict(execute_commands_in_kwargs()),
         )
 
 
 PositionalTypes = TypeVar(
-    "PositionalTypes", Iterable[int], Iterable[float], Iterable[str], Iterable[bool]
+    'PositionalTypes', Iterable[int], Iterable[float], Iterable[str], Iterable[bool]
 )
 KeywordTypes = TypeVar(
-    "KeywordTypes", Dict[str, int], Dict[str, float], Dict[str, str], Dict[str, bool]
+    'KeywordTypes', Dict[str, int], Dict[str, float], Dict[str, str], Dict[str, bool]
 )
 
 
-def incremental_str_maker(str_format="{:03.f}"):
+def incremental_str_maker(str_format='{:03.f}'):
     """Make a function that will produce a (incrementally) new string at every call."""
     i = 0
 
@@ -51,14 +50,14 @@ def incremental_str_maker(str_format="{:03.f}"):
     return mk_next_str
 
 
-unnamed_page = incremental_str_maker(str_format="UnnamedPage{:03.0f}")
+unnamed_page = incremental_str_maker(str_format='UnnamedPage{:03.0f}')
 
 
 def func_name(func):
     """The func.__name__ of a callable func, or makes and returns one if that fails.
     To make one, it calls unamed_func_name which produces incremental names to reduce the chances of clashing"""
     name = name_of_obj(func)
-    if name is None or name == "<lambda>":
+    if name is None or name == '<lambda>':
         return unnamed_page()
     return name
 
@@ -107,7 +106,7 @@ class Objdict(dict):
         if name in self:
             return self[name]
         else:
-            raise AttributeError("No such attribute: " + name)
+            raise AttributeError('No such attribute: ' + name)
 
     def __setattr__(self, name, value):
         self[name] = value
@@ -116,7 +115,7 @@ class Objdict(dict):
         if name in self:
             del self[name]
         else:
-            raise AttributeError("No such attribute: " + name)
+            raise AttributeError('No such attribute: ' + name)
 
 
 def attr_or_key(obj, k):
@@ -151,7 +150,7 @@ def attr_or_key_with_dotpaths(obj, k):
     """
     if isinstance(k, str):
         _obj = obj
-        for kk in k.split("."):
+        for kk in k.split('.'):
             _obj = attr_or_key(_obj, kk)
         return _obj
     else:
@@ -203,7 +202,7 @@ class NodeGetter:
             try:
                 _src = self.item_getter(_src, k)
             except Exception as e:
-                raise KeyError(f"Accessing {path} produced an error: {e}")
+                raise KeyError(f'Accessing {path} produced an error: {e}')
         return _src
 
 
@@ -233,10 +232,10 @@ def build_factory(element_factory, kind, idx):
     """
     Build the factory for user input for VP and VK inputs
     """
-    factory = element_factory[f"{kind}_factory"]
-    kwargs = {"label": f"Enter {kind} {idx + 1}", "key": idx}
-    if element_factory[f"{kind}_type"] is int:
-        kwargs["value"] = 0
+    factory = element_factory[f'{kind}_factory']
+    kwargs = {'label': f'Enter {kind} {idx + 1}', 'key': idx}
+    if element_factory[f'{kind}_type'] is int:
+        kwargs['value'] = 0
     val = factory(**kwargs)
     return val
 
@@ -251,18 +250,18 @@ def build_element_commands(
     """
     if inferred_type in PositionalTypes.__constraints__:
         element_factory, factory_kwargs = build_element_factory_helper(
-            element_factory_for_annot, inferred_type, missing, "positional"
+            element_factory_for_annot, inferred_type, missing, 'positional'
         )
     elif inferred_type in KeywordTypes.__constraints__:
         element_factory, factory_kwargs = build_element_factory_helper(
-            element_factory_for_annot, inferred_type, missing, "keyword"
+            element_factory_for_annot, inferred_type, missing, 'keyword'
         )
     elif inferred_type is not missing:
         element_factory = element_factory_for_annot.get(inferred_type, missing)
-        factory_kwargs = {"label": name}
+        factory_kwargs = {'label': name}
     else:
         element_factory = dflt_element_factory
-        factory_kwargs = {"label": name}
+        factory_kwargs = {'label': name}
     return element_factory, factory_kwargs
 
 
@@ -274,18 +273,18 @@ def build_element_factory(
     """
     if inferred_type in PositionalTypes.__constraints__:
         element_factory, factory_kwargs = build_element_factory_helper(
-            element_factory_for_annot, inferred_type, missing, "positional"
+            element_factory_for_annot, inferred_type, missing, 'positional'
         )
     elif inferred_type in KeywordTypes.__constraints__:
         element_factory, factory_kwargs = build_element_factory_helper(
-            element_factory_for_annot, inferred_type, missing, "keyword"
+            element_factory_for_annot, inferred_type, missing, 'keyword'
         )
     elif inferred_type is not missing:
         element_factory = element_factory_for_annot.get(inferred_type, missing)
-        factory_kwargs = {"label": name}
+        factory_kwargs = {'label': name}
     else:
         element_factory = dflt_element_factory
-        factory_kwargs = {"label": name}
+        factory_kwargs = {'label': name}
     return element_factory, factory_kwargs
 
 
@@ -295,29 +294,29 @@ def build_element_factory_helper(
     """
     Helper to build the element factory for VP and VK arguments
     """
-    if args == "positional":
+    if args == 'positional':
         element_factory = {
-            "base": element_factory_for_annot.get(inferred_type, missing)[0],
-            "input_type": element_factory_for_annot.get(inferred_type, missing)[1],
-            "input_factory": element_factory_for_annot.get(
+            'base': element_factory_for_annot.get(inferred_type, missing)[0],
+            'input_type': element_factory_for_annot.get(inferred_type, missing)[1],
+            'input_factory': element_factory_for_annot.get(
                 element_factory_for_annot.get(inferred_type, missing)[1], missing
             ),
         }
     else:
         element_factory = {
-            "base": element_factory_for_annot.get(inferred_type, missing)[0],
-            "key_type": element_factory_for_annot.get(inferred_type, missing)[1],
-            "key_factory": element_factory_for_annot.get(
+            'base': element_factory_for_annot.get(inferred_type, missing)[0],
+            'key_type': element_factory_for_annot.get(inferred_type, missing)[1],
+            'key_factory': element_factory_for_annot.get(
                 element_factory_for_annot.get(inferred_type, missing)[1], missing
             ),
-            "value_type": element_factory_for_annot.get(inferred_type, missing)[2],
-            "value_factory": element_factory_for_annot.get(
+            'value_type': element_factory_for_annot.get(inferred_type, missing)[2],
+            'value_factory': element_factory_for_annot.get(
                 element_factory_for_annot.get(inferred_type, missing)[2], missing
             ),
         }
     factory_kwargs = {
-        "label": "Enter the number of positional arguments you would like to pass",
-        "value": 0,
+        'label': 'Enter the number of positional arguments you would like to pass',
+        'value': 0,
     }
 
     return element_factory, factory_kwargs
